@@ -1,56 +1,51 @@
 # Tipitaka (Pali Canon)
 #
-# This file documents the multiple versions of the complete
-# Pali Canon of Therevadin Buddhism, also know (in Pali)
-# as the Tipitaka, that are included in this package.
-#
-# It is provided in both "long" and "wide" formats, as each are
-# useful for different types of analysis, and conversion
-# between the two can be slow and error-prone.
+# This file documents the datasets included in the tipitaka package.
 
 
-#' tipitaka: A package for exploring the Pali Canon in R.
+#' tipitaka: Data and Tools for Analyzing the Pali Canon
 #'
-#' The package tipitaka provides access to the complete Pali
+#' The tipitaka package provides access to the complete Pali
 #' Canon, or Tipitaka, from R. The Tipitaka is the canonical
-#' scripture for Therevadin Buddhists worldwide. This version
-#' is largely taken from the Chattha Sangāyana Tipitaka
-#' version 4.0 com;iled by the Vispassana Research Institute,
-#' although edits have been made to conform to the numbering
-#' used by the Pali Text Society. This package provides both
-#' data and tools to facilitate the analysis of these ancient
-#' Pali texts.
+#' scripture for Theravadin Buddhists worldwide. This package
+#' includes the VRI (Vipassana Research Institute) Chattha
+#' Sangayana edition along with tools for working with Pali text.
 #'
-#'
-#' @section Data:
-#' Several data sets are included:
+#' @section Datasets:
 #' \itemize{
-#'   \item tipitaka_raw: the complete text of the Tipitaka
-#'   \item tipitaka_long: the complete Tipitaka in "long" form
-#'   \item tipitaka_wide: the complete Tipitaka in "wide" form
+#'   \item tipitaka_raw: the complete text of the Tipitaka (VRI)
 #'   \item tipitaka_names: the names of each book of the Tipitaka
 #'   \item sutta_pitaka: the names of each volume of the Sutta Pitaka
 #'   \item vinaya_pitaka: the names of each volume of the Vinaya Pitaka
-#'   \item abhidhamma_pitaka: the names of each volume of the Abhidhamma Pitak
-#'   \item sati_sutta_raw: the Mahāsatipatthāna Sutta text
-#'   \item sati_sutta_long: the Mahāsatipatthāna Sutta in "long" form
-#'   \item pali_alphabet: the complete pali alphabet in traditional order
+#'   \item abhidhamma_pitaka: the names of each volume of the Abhidhamma Pitaka
+#'   \item pali_alphabet: the complete Pali alphabet in traditional order
 #'   \item pali_stop_words: a set of "stop words" for Pali
-#'   }
-#'
-#' @section Tools:
-#' A few useful functions are provided for working with Pali text:
-#' \itemize{
-#'   \item pali_lt: less-than function for Pali strings
-#'   \item pali-gt: greater-than function for Pali strings
-#'   \item pali-eq: equals function for Pali strings
-#'   \item pali-sort: sorting function for vectors of pali strings
 #' }
 #'
-#' @docType package
+#' @section Derived Data:
+#' These are computed on demand from \code{tipitaka_raw} on first access:
+#' \itemize{
+#'   \item tipitaka_long: word frequencies per volume
+#'   \item tipitaka_wide: word frequency matrix (volumes x words)
+#' }
+#'
+#' @section Tools:
+#' Functions for working with Pali text:
+#' \itemize{
+#'   \item pali_lt: less-than function for Pali strings
+#'   \item pali_gt: greater-than function for Pali strings
+#'   \item pali_eq: equals function for Pali strings
+#'   \item pali_sort: sorting function for vectors of Pali strings
+#' }
+#'
+#' @section Related Packages:
+#' The companion package \pkg{tipitaka.critical} provides a
+#' lemmatized critical edition of the complete Tipitaka based on
+#' a five-witness collation with sutta-level granularity.
+#'
 #' @name tipitaka
-#' @useDynLib tipitaka
-NULL
+#' @useDynLib tipitaka, .registration = TRUE
+"_PACKAGE"
 
 
 #' Tipitaka text in raw form
@@ -67,35 +62,6 @@ NULL
 "tipitaka_raw"
 
 
-#' Tipitaka in "long" form
-#'
-#' Every word of every volume of the Tipitaka, with one word per
-#' volume per line.
-#'
-#' @format A tibble with the variables:
-#' \describe{
-#' \item{word}{Pali word}
-#' \item{n}{Number of time this word appears in this book}
-#' \item{total}{Ttal number of words in this book}
-#' \item{freq}{Frequency with which this word appears in this book}
-#' \item{book}{Abbreviated book name}
-#' }
-#'
-#' @source Vipassana Research Institute, CST4, April 2020
-"tipitaka_long"
-
-
-#' Tipitaka in "wide" form
-#'
-#' Every word of every volume of the Tipitaka, with one word per
-#' column and one book per line. Each cell is the frequency at
-#' which that word appears in that book.
-#'
-#'
-#' @source Vipassana Research Institute, CST4, April 2020
-"tipitaka_wide"
-
-
 #' Names of each book of the Tipitaka, both abbreviated and
 #' in full. These are easier to read if you call \code{pali_string_fix() first}.
 #'
@@ -106,9 +72,11 @@ NULL
 #' }
 #'
 #' @examples
-#' # Clean up the Unicode characters to make things more readble:
+#' \donttest{
+#' # Clean up the Unicode characters to make things more readable:
 #' tipitaka_names$name <-
 #'   stringi::stri_unescape_unicode(tipitaka_names$name)
+#' }
 #'
 "tipitaka_names"
 
@@ -126,20 +94,17 @@ NULL
 #' }
 #'
 #' @examples
-#' # Clean up the Unicode characters to make things more readble:
+#' \donttest{
+#' # Clean up the Unicode characters to make things more readable:
 #' sutta_pitaka$name <-
 #'   stringi::stri_unescape_unicode(sutta_pitaka$name)
+#' }
+#' \donttest{
 #' # Count all the words in the Suttas:
 #' sum(
 #'   unique(
 #'     tipitaka_long[tipitaka_long$book %in% sutta_pitaka$book, "total"]))
-#'
-#' # Count another way:
-#' sum(tipitaka_long[tipitaka_long$book %in% sutta_pitaka$book, "n"])
-#'
-#' # Create a tibble of just the Suttas
-#' sutta_wide <-
-#'   tipitaka_wide[row.names(tipitaka_wide) %in% sutta_pitaka$book,]
+#' }
 #'
 "sutta_pitaka"
 
@@ -157,12 +122,15 @@ NULL
 #'}
 #'
 #' @examples
-#' # Clean up the Unicode characters to make things more readble:
+#' \donttest{
+#' # Clean up the Unicode characters to make things more readable:
 #' vinaya_pitaka$name <-
 #'   stringi::stri_unescape_unicode(vinaya_pitaka$name)
-#'
+#' }
+#' \donttest{
 #' # Count all the words in the Vinaya Pitaka:
 #' sum(tipitaka_long[tipitaka_long$book %in% vinaya_pitaka$book, "n"])
+#' }
 #'
 "vinaya_pitaka"
 
@@ -181,51 +149,33 @@ NULL
 #'}\
 #'
 #' @examples
-#' # Clean up the Unicode characters to make things more readble:
+#' \donttest{
+#' # Clean up the Unicode characters to make things more readable:
 #' abhidhamma_pitaka$name <-
 #'   stringi::stri_unescape_unicode(abhidhamma_pitaka$name)
-#'
+#' }
+#' \donttest{
 #' # Count all the words in the Abhidhamma Pitaka:
 #' sum(tipitaka_long[tipitaka_long$book %in% abhidhamma_pitaka$book, "n"])
+#' }
 #'
 "abhidhamma_pitaka"
 
 
 
-#' Mahāsatipatthāna Sutta in "long" form
-#'
-#' The Mahāsatipatthāna Sutta or Discourse on the Establishing
-#' of Mindfulness in "long" form.
-#'
-#' @source Vipassana Research Institute, CST4, April 2020
-"sati_sutta_long"
-
-#' Mahāsatipatthāna Sutta text in raw form
-#'
-#' The unprocessed text of the Mahāsatipatthāna Sutta
-#'
-#' @format A tibble with the variable:
-#' \describe{
-#' \item{text}{Complete text}
-#' }
-#'
-#' @source Vipassana Research Institute, CST4, April 2020
-"sati_sutta_raw"
-
-
 #' Tentative set of "stop words" for Pali
 #'
 #' A list of all declinables and particles from the PTS
 #' Pali-English Dictionary.
 #'
 #' @examples
-#' # Find most common words in the Mahāsatipatthāna Sutta excluding stop words
-#' library(dplyr)
-#' sati_sutta_long %>%
-#'   anti_join(pali_stop_words, by = "word") %>%
-#'   arrange(desc(freq))
+#' \donttest{
+#' # Show top content words in the Tipitaka (excluding stop words)
+#' content_words <- tipitaka_long[!tipitaka_long$word %in% pali_stop_words$word, ]
+#' head(content_words[order(-content_words$n), ], 10)
+#' }
 #'
-#' @source \url{https://dsalsrv04.uchicago.edu/dictionaries/pali/}
+#' @source \url{https://dsal.uchicago.edu/dictionaries/pali/}
 "pali_stop_words"
 
 
@@ -240,4 +190,3 @@ NULL
 #' match("b", pali_alphabet) < match("c", pali_alphabet)
 #'
 "pali_alphabet"
-
